@@ -1,10 +1,9 @@
 #!/usr/bin/perl -w
-# Copyright (c) 2011-2013 Sullivan Beck.  All rights reserved.
+# Copyright (c) 2011-2015 Sullivan Beck.  All rights reserved.
 # This program is free software; you can redistribute it and/or modify it
 # under the same terms as Perl itself.
 
-$Data{'langfam'}{'alias'} = {
-};
+$Data{'langfam'}{'link'} = [];
 
 ################################################################################
 
